_`umbra.reporter`
=================

.. automodule:: umbra.reporter

Module Attributes
-----------------

.. attribute:: umbra.reporter.LOGGER

.. attribute:: umbra.reporter.UI_FILE

Functions
---------

.. autofunction:: baseExceptionHandler

.. autofunction:: systemExitExceptionHandler

.. autofunction:: criticalExceptionHandler

.. autofunction:: installExceptionReporter

.. autofunction:: uninstallExceptionReporter

.. autofunction:: enableExceptionReporter

.. autofunction:: disableExceptionReporter

Classes
-------

.. autoclass:: Reporter
	:show-inheritance:
	:members:

